@@ -7,9 +7,9 @@ use AnyEvent::Pcap::Utils;
 use Net::Pcap;
 use base qw(Class::Accessor::Fast);
 
-our $VERSION = '0.00002';
+our $VERSION = '0.00003';
 
-__PACKAGE__->mk_accessors($_) for qw(utils device filter packet_handler fd);
+__PACKAGE__->mk_accessors($_) for qw(utils device filter packet_handler fd timeout);
 
 sub new {
     my $class = shift;
@@ -28,7 +28,8 @@ sub _setup_pcap {
       ->();
     croak $err if $err;
 
-    my $pcap = Net::Pcap::pcap_open_live( $device, 1024, 1, 0, \$err );
+    my $timeout = $self->timeout || 0;
+    my $pcap = Net::Pcap::pcap_open_live( $device, 1024, 1, $timeout, \$err );
     croak $err if $err;
 
     my ( $address, $netmask );
@@ -94,17 +95,21 @@ AnyEvent::Pcap - Net::Pcap wrapper with AnyEvent
   $a_pcap = AnyEvent::Pcap->new(
       device         => "eth0",
       filter         => "tcp port 80",
+      timeout        => 1000,
       packet_handler => sub {
-          my $header = shift;
-          my $packet = shift;
+          my $io     = pop;
+          while (@_) {
+              my $header = shift;
+              my $packet = shift;
   
-          # you can use utils to get an NetPacket::TCP object.
-          my $tcp = $a_pcap->utils->extract_tcp_packet($packet);
+              # you can use utils to get an NetPacket::TCP object.
+              my $tcp = $a_pcap->utils->extract_tcp_packet($packet);
 
-          # or ...
-          $tcp = AnyEvent::Pcap::Utils->extract_tcp_packet($packet); 
+              # or ...
+              $tcp = AnyEvent::Pcap::Utils->extract_tcp_packet($packet); 
 
-          # do something....
+              # do something....
+          }
       }
   );
   
@@ -133,8 +138,15 @@ Also you can use its utils to get NetPacket::IP or NetPacket::TCP object.
       # Default is NULL
       filter => "tcp port 80",
   
+      # How much time wait befor flush pcap buffer
+      # Default is 0 (unlimited)
+      timeout => 1000,
+  
       # set your coderef
       packet_handler => sub {
+          my $io     = pop;
+
+          # get first pair....
           my $header = shift;
           my $packet = shift;
   
@@ -174,6 +186,8 @@ Running AnyEvent loop.
 
 =item packet_handler(I<[CODEREF]>)
 
+=item timeout(I<[INTEGER]>)
+
 =back
 
 =head1 AUTHOR
